@@ -1,8 +1,9 @@
 package OpenSearch;
 use strict;
 use warnings;
-use Moose;
-use feature qw(signatures);
+use Moo;
+use Types::Standard qw(InstanceOf);
+use feature         qw(signatures);
 no warnings qw(experimental::signatures);
 use Data::Dumper;
 use OpenSearch::Base;
@@ -12,18 +13,18 @@ use OpenSearch::Remote;
 use OpenSearch::Search;
 use OpenSearch::Index;
 use OpenSearch::Document;
+use OpenSearch::Security;
 
-our $VERSION = '0.92';
+our $VERSION = '0.94';
 
-has 'base' => (
-  is      => 'rw',
-  isa     => 'OpenSearch::Base',
-  lazy    => 1,
-  default => sub { OpenSearch::Base->initialize; }
+has '_base' => (
+  is       => 'rw',
+  isa      => InstanceOf ['OpenSearch::Base'],
+  init_arg => undef,
 );
 
 sub BUILD( $self, $args ) {
-  $self->base( OpenSearch::Base->new(
+  $self->_base( OpenSearch::Base->new(
     user            => $args->{user},
     pass            => $args->{pass},
     hosts           => $args->{hosts},
@@ -37,23 +38,27 @@ sub BUILD( $self, $args ) {
 }
 
 sub cluster($self) {
-  return ( OpenSearch::Cluster->new );
+  return ( OpenSearch::Cluster->new( _base => $self->_base ) );
 }
 
 sub remote($self) {
-  return ( OpenSearch::Remote->new );
+  return ( OpenSearch::Remote->new( _base => $self->_base ) );
 }
 
 sub search($self) {
-  return ( OpenSearch::Search->new );
+  return ( OpenSearch::Search->new( _base => $self->_base ) );
 }
 
 sub index($self) {
-  return ( OpenSearch::Index->new );
+  return ( OpenSearch::Index->new( _base => $self->_base ) );
 }
 
 sub document($self) {
-  return ( OpenSearch::Document->new );
+  return ( OpenSearch::Document->new( _base => $self->_base ) );
+}
+
+sub security($self) {
+  return ( OpenSearch::Security->new( _base => $self->_base ) );
 }
 
 1;
@@ -85,6 +90,7 @@ C<OpenSearch> - Unofficial Perl client for OpenSearch (https://opensearch.org/)
   my $search  = $opensearch->search;
   my $index   = $opensearch->index;
   my $document = $opensearch->document;
+  my $security = $opensearch->security;
 
 =head1 DESCRIPTION
 
@@ -105,18 +111,25 @@ endpoints are (partially) supported:
 
 =item * Document
 
+=item * Security
+
 =back
 
 =head1 IMPORTANT
 
 This module is still in development and should not be used in production unless you
 are willing to accept the risks associated with using an incomplete and untested
-module. It heavily relies on L<Moose> and L<Mojo::UserAgent>. Due to the use of
-L<Moose>, startup time is slower than other modules. However, the use of L<Mojo::UserAgent>
-allows for asynchronous requests to be made to the OpenSearch server.
+module. It heavily relies on L<Moo> and L<Mojo::UserAgent>. Due to the use of L<Mojo::UserAgent>,
+it is possible to use asynchronous requests (including promises).
 
 CERTIFICATE AUTHENTICATION IS NOT YET TESTED! Feel free to test it and report back to me.
 
+=head1 ATTRIBUTES/PARAMATERS OF API ENDPOINTS
+
+For a list of available parameters for all supported API Endpoints see the OpenSearch API documentation.
+As an alternative you can have a look in the Source of the corresponding C<OpenSearch::Parameters::*>
+modules.
+
 =head1 METHODS
 
 =head2 new
@@ -143,6 +156,10 @@ Returns a new instance of C<OpenSearch::Index>.
 
 Returns a new instance of C<OpenSearch::Document>.
 
+=head2 security
+
+Returns a new instance of C<OpenSearch::Security>.
+
 =head1 ATTRIBUTES
 
 =over 4
@@ -178,7 +195,9 @@ A boolean value indicating whether to clear the attributes of most objects.
 =item * async
 
 A boolean value indicating whether to use asynchronous requests when connecting to the OpenSearch server.
-This will return a L<Mojo::Promise> object instead of the actual response.
+When set to true, all requests will return a L<Mojo::Promise> object that will (eventually) resolve to 
+an L<OpenSearch::Response> object. If it is set to false, all requests will return an L<OpenSearch::Response> 
+object.
 
 =item * max_connections
 
@@ -267,3 +286,6 @@ C<benchmark-index-async.pl> script:
 
 C<OpenSearch> Perl Module was written by Sebastian Grenz, C<< <git at fail.ninja> >>
 
+=head1 CONTRIBUTORS
+Nicolas Franck (https://github.com/nicolasfranck)
+
