@@ -1,18 +1,17 @@
 package OpenSearch::Cluster::AllocationExplain;
 use strict;
 use warnings;
+use Moo;
+use Types::Standard qw(InstanceOf);
 use feature qw(signatures);
 no warnings qw(experimental::signatures);
-use Moose;
 
 with 'OpenSearch::Parameters::Cluster::AllocationExplain';
 
 has '_base' => (
   is       => 'rw',
-  isa      => 'OpenSearch::Base',
-  required => 0,
-  lazy     => 1,
-  default  => sub { OpenSearch::Base->instance; }
+  isa      => InstanceOf['OpenSearch::Base'],
+  required => 1,
 );
 
 sub execute($self) {
