@@ -1,18 +1,17 @@
 package OpenSearch::Index::GetMappings;
 use strict;
 use warnings;
+use Moo;
+use Types::Standard qw(InstanceOf);
 use feature qw(signatures);
 no warnings qw(experimental::signatures);
-use Moose;
 
 with 'OpenSearch::Parameters::Index::GetMappings';
 
 has '_base' => (
   is       => 'rw',
-  isa      => 'OpenSearch::Base',
-  required => 0,
-  lazy     => 1,
-  default  => sub { OpenSearch::Base->instance; }
+  isa      => InstanceOf['OpenSearch::Base'],
+  required => 1,
 );
 
 sub execute($self) {
@@ -20,4 +19,5 @@ sub execute($self) {
     $self->_base->_get( $self, [ $self->index, '_mapping', ( $self->field ? ( 'field', $self->field ) : () ) ] );
 }
 
+
 1;
